package com.muyu.cloud.pay.controller;

import com.dtflys.forest.springboot.annotation.ForestScannerRegister;
import com.muyu.cloud.pay.domain.OrderPayCustomer;
import com.muyu.cloud.pay.domain.req.CustomerListReq;
import com.muyu.cloud.pay.domain.resp.CustomerResp;
import com.muyu.cloud.pay.service.OrderPayCustomerService;
import com.muyu.common.core.domain.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author: DongZeLiang
 * @date: 2024/7/30
 * @Description: 支付客户控制层
 * @Version: 1.0
 */
@Log4j2
@RestController
@RequestMapping("/customer")
@Tag(name = "客户控制层", description = "进行客户管理、查看等相关操作")
public class OrderPayCustomerController {

    public OrderPayCustomerController () {
        log.info("forest扫描路径:{}", ForestScannerRegister.getBasePackages());
    }

    /**
     * 客户业务层
     */
    @Autowired
    private OrderPayCustomerService orderPayCustomerService;

    /**
     * 查询所有的客户
     * @param customerListReq 客户列表请求参数
     * @return 客户列表
     */
    @RequestMapping(path = "/list", method = RequestMethod.POST)
    @Operation(summary = "查看客户", description = "根据客户的名称、编码、是否开启等可以进行客户的筛选")
    public Result<List<CustomerResp>> selectList(
            @Validated @RequestBody CustomerListReq customerListReq) {
        return Result.success(
                orderPayCustomerService.selectList(customerListReq)
        );
    }

    /**
     * 获取所有客户的
     * @return 客户集合
     */
    @GetMapping("/all")
    @Operation(summary = "获取未接入的客户", description = "调用nacosAPI获取所有的微服务名称，作为支付中台的客户")
    @Schema(description = "获取未接入的客户", defaultValue = "[\"客户1\",\"客户2\"]", type = "List")
    public Result<List<String>> getCustomerAllList(){
        return Result.success(
                orderPayCustomerService.getCustomerAllList()
        );
    }
}
